ArcLinearOperator

Struct ArcLinearOperator 

pub struct ArcLinearOperator<T, V>
where T: TensorLike, V: Clone + Hash + Eq + Send + Sync + Debug,
{ pub mpo: Arc<TreeTN<T, V>>, pub input_mapping: HashMap<V, IndexMapping<T::Index>>, pub output_mapping: HashMap<V, IndexMapping<T::Index>>, }
LinearOperator with Arc-based Copy-on-Write semantics.

This wrapper uses Arc for the internal MPO to enable cheap cloning and efficient sharing. When mutation is needed, make_mut performs a clone only if there are other references.

Fields

mpo: Arc<TreeTN<T, V>>

The MPO with internal index IDs (wrapped in Arc for CoW)

input_mapping: HashMap<V, IndexMapping<T::Index>>

Input index mapping: node -> (true s_in, internal s_in_tmp)

output_mapping: HashMap<V, IndexMapping<T::Index>>

Output index mapping: node -> (true s_out, internal s_out_tmp)

Implementations

Source

impl<T, V> ArcLinearOperator<T, V>
where T: TensorLike, T::Index: IndexLike + Clone, <T::Index as IndexLike>::Id: Clone + Hash + Eq + Ord + Debug + Send + Sync, V: Clone + Hash + Eq + Ord + Send + Sync + Debug,

pub fn from_linear_operator(op: LinearOperator<T, V>) -> Self

Create from an existing LinearOperator.

pub fn new( mpo: TreeTN<T, V>, input_mapping: HashMap<V, IndexMapping<T::Index>>, output_mapping: HashMap<V, IndexMapping<T::Index>>, ) -> Self

Create a new ArcLinearOperator.

pub fn mpo_mut(&mut self) -> &mut TreeTN<T, V>

Get a mutable reference to the MPO, cloning if necessary.

This implements Copy-on-Write semantics: if this is the only reference, no copy is made. If there are other references, the MPO is cloned first.

pub fn mpo(&self) -> &TreeTN<T, V>

Get an immutable reference to the MPO.

pub fn into_linear_operator(self) -> LinearOperator<T, V>

Convert back to a LinearOperator (unwraps Arc if possible).

pub fn get_input_mapping(&self, node: &V) -> Option<&IndexMapping<T::Index>>

Get input mapping for a node.

pub fn get_output_mapping(&self, node: &V) -> Option<&IndexMapping<T::Index>>

Get output mapping for a node.

pub fn input_mappings(&self) -> &HashMap<V, IndexMapping<T::Index>>

Get all input mappings.

pub fn output_mappings(&self) -> &HashMap<V, IndexMapping<T::Index>>

Get all output mappings.

pub fn node_names(&self) -> HashSet<V>

Get node names covered by this operator.