pub fn contract_naive_to_treetn<T, V>(
tn_a: &TreeTN<T, V>,
tn_b: &TreeTN<T, V>,
center: &V,
_max_rank: Option<usize>,
_svd_policy: Option<SvdTruncationPolicy>,
_qr_rtol: Option<f64>,
) -> Result<TreeTN<T, V>>Expand description
Contract two TreeTNs using naive contraction, then decompose back to TreeTN.
This method:
- Contracts both networks to full tensors
- Contracts the tensors along common (site) indices
- Decomposes the result back to a TreeTN using the original topology
This is O(exp(n)) in memory and is primarily useful for debugging and testing.